==> haystack-0.4.1.tar.gz: lib/src/io/HZincWriter.dart <==
///
/// Copyright (c) 2015, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.hzinc_writer;

import '../HVal.dart';
import '../HMarker.dart';
import '../HGrid.dart';

/// HZincWriter is used to write grids in the Zinc format
///
/// See [Project Haystack](http://project-haystack.org/doc/Zinc)
class HZincWriter {

  /** Write using UTF-8 */
  factory HZincWriter(StringBuffer out) {
    return new HZincWriter._(out);
  }

  /** Write a grid to an in-memory a string */
  static String gridToString(HGrid grid) {
    StringBuffer out = new StringBuffer(/*grid.numCols() * grid.numRows() * 16*/);
    new HZincWriter(out).writeGrid(grid);
    return out.toString();
  }

  HZincWriter._(this._out);

  /** Write a grid */
  void writeGrid(HGrid grid) {
    // meta
    _out.write("ver:\"2.0\"");
    writeMeta(grid.meta);
    _out.write('\n');

    // cols
    for (int i=0; i<grid.numCols; ++i) {
      if (i > 0) _out.write(',');
      writeCol(grid.colByIndex(i));
    }
    _out.write('\n');

    // rows
    for (int i=0; i<grid.numRows; ++i) {
      writeRow(grid, grid.row(i));
      _out.write('\n');
    }
  }

  void writeMeta(HDict meta) {
    if (meta.isEmpty()) return;
    for (Iterator it = meta.iterator(); it.moveNext(); ) {
      DictEntry entry = it.current;
      String name = entry.key;
      HVal val = entry.val as HVal;
      _out.write(' ');
      _out.write(name);
      if (val != HMarker.VAL) {
        _out.write(':');
        _out.write(val.toZinc());
      }
    }
  }

  void writeCol(HCol col) {
    _out.write(col.name);
    writeMeta(col.meta);
  }

  void writeRow(HGrid grid, HRow row) {
    for (int i=0; i<grid.numCols; ++i) {
      HVal val = row.getByCol(grid.colByIndex(i), checked:false);
      if (i > 0) _out.write(',');
      if (val == null) {
        if (i == 0) _out.write('N');
      } else {
        _out.write(val.toZinc());
      }
    }
  }

  StringBuffer _out;
}

==> haystack-0.4.16.tar.gz: lib/src/io/HZincWriter.dart <==
///
/// Copyright (c) 2015, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.hzinc_writer;

import '../HVal.dart';
import '../HMarker.dart';
import '../HGrid.dart';

/// HZincWriter is used to write grids in the Zinc format
///
/// See [Project Haystack](http://project-haystack.org/doc/Zinc)
class HZincWriter {

  /** Write using UTF-8 */
  factory HZincWriter(StringBuffer out) {
    return new HZincWriter._(out);
  }

  /** Write a grid to an in-memory a string */
  static String gridToString(HGrid grid) {
    StringBuffer out = new StringBuffer(/*grid.numCols() * grid.numRows() * 16*/);
    new HZincWriter(out).writeGrid(grid);
    return out.toString();
  }

  HZincWriter._(this._out);

  /** Write a grid */
  void writeGrid(HGrid grid) {
    // meta
    _out.write("ver:\"2.0\"");
    writeMeta(grid.meta);
    _out.write('\n');

    // cols
    for (int i=0; i<grid.numCols; ++i) {
      if (i > 0) _out.write(',');
      writeCol(grid.colByIndex(i));
    }
    _out.write('\n');

    // rows
    for (int i=0; i<grid.numRows; ++i) {
      writeRow(grid, grid.row(i));
      _out.write('\n');
    }
  }

  void writeMeta(HDict meta) {
    if (meta.isEmpty) return;
    for (Iterator it = meta.iterator(); it.moveNext(); ) {
      DictEntry entry = it.current;
      String name = entry.key;
      HVal val = entry.val as HVal;
      _out.write(' ');
      _out.write(name);
      if (val != HMarker.VAL) {
        _out.write(':');
        _out.write(val.toZinc());
      }
    }
  }

  void writeCol(HCol col) {
    _out.write(col.name);
    writeMeta(col.meta);
  }

  void writeRow(HGrid grid, HRow row) {
    for (int i=0; i<grid.numCols; ++i) {
      HVal val = row.getByCol(grid.colByIndex(i), checked:false);
      if (i > 0) _out.write(',');
      if (val == null) {
        if (i == 0) _out.write('N');
      } else {
        _out.write(val.toZinc());
      }
    }
  }

  StringBuffer _out;
}
